This is an automated email from the ASF dual-hosted git repository.

rohit pushed a commit to branch debian9-systemvmtemplate
in repository https://gitbox.apache.org/repos/asf/cloudstack.git

commit a678ba7b6341003ee59404090c21b6c1cd9f7caf
Author: Rohit Yadav <rohit.ya...@shapeblue.com>
AuthorDate: Wed Dec 13 16:49:52 2017 +0530

    increase timeout as things run slow in nested-environments
    
    Signed-off-by: Rohit Yadav <rohit.ya...@shapeblue.com>
---
 test/integration/smoke/test_deploy_vm_root_resize.py | 8 ++++----
 test/integration/smoke/test_ssvm.py                  | 4 ++--
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/test/integration/smoke/test_ssvm.py 
b/test/integration/smoke/test_ssvm.py
index 41db1ab..f20003b 100644
--- a/test/integration/smoke/test_ssvm.py
+++ b/test/integration/smoke/test_ssvm.py
@@ -73,7 +73,7 @@ class TestSSVMs(cloudstackTestCase):
                 return list_host_response[0].state == 'Up', None
             return False, None
 
-        res, _ = wait_until(3, self.services["sleep"], checkRunningAgent)
+        res, _ = wait_until(3, 300, checkRunningAgent)
         if not res:
             raise Exception("Failed to wait for SSVM agent to be Up")
 
@@ -99,7 +99,7 @@ class TestSSVMs(cloudstackTestCase):
                 return ssvm_response.state == 'Running', ssvm_response
             return False, None
 
-        res, ssvm_response = wait_until(3, self.services["sleep"], 
checkRunningState)
+        res, ssvm_response = wait_until(3, 300, checkRunningState)
         if not res:
             self.fail("Failed to reach systemvm state to Running")
         return ssvm_response

diff --git a/test/integration/smoke/test_deploy_vm_root_resize.py 
b/test/integration/smoke/test_deploy_vm_root_resize.py
index 4855099..463b93e 100755
--- a/test/integration/smoke/test_deploy_vm_root_resize.py
+++ b/test/integration/smoke/test_deploy_vm_root_resize.py
@@ -126,9 +126,9 @@ class TestDeployVmRootSize(cloudstackTestCase):
              if cls.restartreq:
                 cls.restartServer()
 
                 #Giving 30 seconds to management to warm-up,
                 #Experienced failures when trying to deploy a VM exactly when 
management came up
-                time.sleep(30)
+                time.sleep(90)
 
         #create a service offering
         cls.service_offering = ServiceOffering.create(
@@ -159,9 +159,9 @@ class TestDeployVmRootSize(cloudstackTestCase):
                                    tags="")
                 cls.restartServer()
 
                 #Giving 30 seconds to management to warm-up,
                 #Experienced failures when trying to deploy a VM exactly when 
management came up
-                time.sleep(30)
+                time.sleep(90)
 
             cleanup_resources(cls.api_client, cls._cleanup)
         except Exception as e:
@@ -126,9 +126,9 @@ class TestDeployVmRootSize(cloudstackTestCase):
                 cls.restartServer()
 
-                #Giving 30 seconds to management to warm-up,
+                #Giving 90 seconds to management to warm-up,
                 #Experienced failures when trying to deploy a VM exactly when 
management came up
@@ -159,9 +159,9 @@ class TestDeployVmRootSize(cloudstackTestCase):
                 cls.restartServer()
 
-                #Giving 30 seconds to management to warm-up,
+                #Giving 90 seconds to management to warm-up,
                 #Experienced failures when trying to deploy a VM exactly when 
management came up
-- 
To stop receiving notification emails like this one, please contact
"commits@cloudstack.apache.org" <commits@cloudstack.apache.org>.

Reply via email to